=================
How to contribute
=================

Contributions in any form are welcome, including:

* Documentation improvements
* Additional tests
* New models
* New features to existing models
* UI design

Discussions take place at foresee channel on slack

`join us on slack <https://join.slack.com/t/openstatworkspace/shared_invite/zt-e6cemrxs-dmHBIpHrZE_U0iciJBu6sA>`_
